@@ -5,11 +5,12 @@
 //! * Plots containing NaN or Infinity are ignored.
 //! * After 8 plots, the colors cycle back and are repeated.
 //!
-use core::fmt::Write;
 
-//pub use tagger;
+mod render;
 mod util;
-use core::borrow::Borrow;
+
+use std::borrow::Borrow;
+use std::fmt;
 
 ///The number of unique colors.
 const NUM_COLORS: usize = 8;
@@ -19,10 +20,6 @@ const WIDTH: f64 = 800.0;
 ///The height of the svg tag.
 const HEIGHT: f64 = 500.0;
 
-use core::fmt;
-
-mod render;
-
 ///Used internally to implement [`Names`]
 struct NamesStruct<A, B, C, D, E, F> {
     title: A,
@@ -139,7 +136,7 @@ pub fn moveable_format(func: impl Fn(&mut fmt::Formatter) -> fmt::Result) -> imp
 
 /// Default theme using css variables (with light theme defaults if the variables are not set).
 pub const HTML_CONFIG_CSS_VARIABLE_DEFAULT: &str = "<style>.poloto {\
-    font-family: \"Arial\";\
+    font-family: sans-serif;\
     stroke-width:2;\
     }\
     .poloto_text{fill: var(--poloto_fg_color,black);}\
@@ -164,7 +161,7 @@ pub const HTML_CONFIG_CSS_VARIABLE_DEFAULT: &str = "<style>.poloto {\
 
 /// Default light theme
 pub const HTML_CONFIG_LIGHT_DEFAULT: &str = "<style>.poloto {\
-    font-family: \"Arial\";\
+    font-family: sans-serif;\
     stroke-width:2;\
     }\
     .poloto_text{fill: black;}\
@@ -189,7 +186,7 @@ pub const HTML_CONFIG_LIGHT_DEFAULT: &str = "<style>.poloto {\
 
 /// Default dark theme
 pub const HTML_CONFIG_DARK_DEFAULT: &str = "<style>.poloto {\
-    font-family: \"Arial\";\
+    font-family: sans-serif;\
     stroke-width:2;\
     }\
     .poloto_text{fill: white;}\
@@ -282,23 +279,27 @@ pub struct Plotter<'a> {
 
 impl<'a> Plotter<'a> {
     /// Create a line from plots.
+    /// Can be stylized using the `.poloto[N]stroke` css class.
     ///
     /// ```
     /// let data = [[1.0,4.0], [2.0,5.0], [3.0,6.0]];
     /// let mut plotter = poloto::plot("title", "x", "y");
     /// plotter.line("", &data);
     /// ```
-    pub fn line<I, J,K>(&mut self, name: impl Display + 'a, plots: I) -> &mut Self
+    pub fn line<I, J, K>(&mut self, name: impl Display + 'a, plots: I) -> &mut Self
     where
         I: IntoIterator<Item = J>,
         I::IntoIter: Clone + 'a,
         J: Borrow<[K; 2]>,
-        K:Into<f64>+Copy
+        K: Into<f64> + Copy,
     {
         self.plots.push(Plot {
             plot_type: PlotType::Line,
             plots: Box::new(PlotStruct::new(
-                plots.into_iter().map(|x| *x.borrow()).map(|[x,y]|[x.into(),y.into()]),
+                plots
+                    .into_iter()
+                    .map(|x| *x.borrow())
+                    .map(|[x, y]| [x.into(), y.into()]),
                 name,
             )),
         });
@@ -306,47 +307,54 @@ impl<'a> Plotter<'a> {
     }
 
     /// Create a line from plots that will be filled underneath.
+    /// Can be stylized using the `.poloto[N]fill` css class.
     ///
     /// ```
     /// let data = [[1.0,4.0], [2.0,5.0], [3.0,6.0]];
     /// let mut plotter = poloto::plot("title", "x", "y");
     /// plotter.line_fill("", &data);
     /// ```
-    pub fn line_fill<I, J,K>(&mut self, name: impl Display + 'a, plots: I) -> &mut Self
+    pub fn line_fill<I, J, K>(&mut self, name: impl Display + 'a, plots: I) -> &mut Self
     where
         I: IntoIterator<Item = J>,
         I::IntoIter: Clone + 'a,
         J: Borrow<[K; 2]>,
-        K:Into<f64>+Copy
+        K: Into<f64> + Copy,
     {
         self.plots.push(Plot {
             plot_type: PlotType::LineFill,
             plots: Box::new(PlotStruct::new(
-                plots.into_iter().map(|x| *x.borrow()).map(|[x,y]|[x.into(),y.into()]),
+                plots
+                    .into_iter()
+                    .map(|x| *x.borrow())
+                    .map(|[x, y]| [x.into(), y.into()]),
                 name,
             )),
         });
         self
     }
 
-    /// Create a scatter plot from plots.
+    /// Create a scatter plot from plots. Can be stylized using the `.poloto[N]fill` css class.
     ///
     /// ```
     /// let data = [[1.0,4.0], [2.0,5.0], [3.0,6.0]];
     /// let mut plotter = poloto::plot("title", "x", "y");
     /// plotter.scatter("", &data);
     /// ```
-    pub fn scatter<I, J,K>(&mut self, name: impl Display + 'a, plots: I) -> &mut Self
+    pub fn scatter<I, J, K>(&mut self, name: impl Display + 'a, plots: I) -> &mut Self
     where
         I: IntoIterator<Item = J>,
         I::IntoIter: Clone + 'a,
         J: Borrow<[K; 2]>,
-        K:Into<f64>+Copy
+        K: Into<f64> + Copy,
     {
         self.plots.push(Plot {
             plot_type: PlotType::Scatter,
             plots: Box::new(PlotStruct::new(
-                plots.into_iter().map(|x| *x.borrow()).map(|[x,y]|[x.into(),y.into()]),
+                plots
+                    .into_iter()
+                    .map(|x| *x.borrow())
+                    .map(|[x, y]| [x.into(), y.into()]),
                 name,
             )),
         });
@@ -354,24 +362,27 @@ impl<'a> Plotter<'a> {
     }
 
     /// Create a histogram from plots.
-    /// Each bar's left side will line up with a point
+    /// Each bar's left side will line up with a point. Can be stylized using the `.poloto[N]fill` css class.
     ///
     /// ```
     /// let data = [[1.0,4.0], [2.0,5.0], [3.0,6.0]];
     /// let mut plotter = poloto::plot("title", "x", "y");
     /// plotter.histogram("", &data);
     /// ```
-    pub fn histogram<I, J,K>(&mut self, name: impl Display + 'a, plots: I) -> &mut Self
+    pub fn histogram<I, J, K>(&mut self, name: impl Display + 'a, plots: I) -> &mut Self
     where
         I: IntoIterator<Item = J>,
         I::IntoIter: Clone + 'a,
         J: Borrow<[K; 2]>,
-        K:Into<f64>+Copy
+        K: Into<f64> + Copy,
     {
         self.plots.push(Plot {
             plot_type: PlotType::Histo,
             plots: Box::new(PlotStruct::new(
-                plots.into_iter().map(|x| *x.borrow()).map(|[x,y]|[x.into(),y.into()]),
+                plots
+                    .into_iter()
+                    .map(|x| *x.borrow())
+                    .map(|[x, y]| [x.into(), y.into()]),
                 name,
             )),
         });
@@ -400,7 +411,6 @@ impl<'a> Plotter<'a> {
     /// plotter.line("", &data);
     /// plotter.render_io(std::io::stdout()).unwrap();
     /// ```
-    
     pub fn render_io<T: std::io::Write>(self, writer: T) -> fmt::Result {
         self.render(tagger::upgrade(writer))
     }
@@ -418,7 +428,6 @@ impl<'a> Plotter<'a> {
     /// let mut s = String::new();
     /// plotter.render(&mut s).unwrap();
     /// ```
-    
     pub fn render<T: fmt::Write>(self, writer: T) -> fmt::Result {
         let mut root = tagger::Element::new(writer);
 
